```{include} ../README.md
```

______________________________________________________________________

::::{grid} 1 1 2 2
:gutter: 2

:::{grid-item-card} Tutorials
:link: tutorials/index
:link-type: doc
:class-card: sd-rounded-3

Topic driven themed lessons.
:::

:::{grid-item-card} How-To Guides
:link: howtos/index
:link-type: doc
:class-card: sd-rounded-3

Focused guides for common tasks.
:::

:::{grid-item-card} Explanation
:link: explanation/index
:link-type: doc
:class-card: sd-rounded-3

Deeper understanding awaits.
:::

:::{grid-item-card} Reference
:link: api/index
:link-type: doc
:class-card: sd-rounded-3

No fuss facts.
:::

::::

Choose your approach to learning and `pyvista-js` knowledge discovery
([Diátaxis](https://diataxis.fr/)).

______________________________________________________________________

## Links

- [GitHub Repository](https://github.com/tkoyama010/pyvista-js)
- [Issue Tracker](https://github.com/tkoyama010/pyvista-js/issues)

```{toctree}
:maxdepth: 1
:hidden:
:caption: Getting Started

Installation <self>
```

```{toctree}
:maxdepth: 1
:hidden:
:caption: Contents

tutorials/index
howtos/index
explanation/index
api/index
```

```{toctree}
:maxdepth: 1
:hidden:
:caption: Demos

stlite_demo
```
